@@ -31,11 +31,11 @@
    libcurl) */
 #if (defined(_WIN32) || defined(__WIN32__)) && !defined(WIN32)
 #  define WIN32
-#endif
+#endif /* (defined(_WIN32) || defined(__WIN32__)) && !defined(WIN32) */
 
 #ifdef __cplusplus
 extern "C" {
-#endif
+#endif /* defined(__cplusplus) */
 
 #include <stdlib.h>
 #if defined(_MSC_VER) && (_MSC_VER < 1800)
@@ -43,9 +43,9 @@ extern "C" {
    compliant.  See compiler macros and version number in
    https://sourceforge.net/p/predef/wiki/Compilers/ */
 #  include <stdint.h>
-#else /* !defined(_MSC_VER) || (_MSC_VER >= 1800) */
+#else /* !(defined(_MSC_VER) && (_MSC_VER < 1800)) */
 #  include <inttypes.h>
-#endif /* !defined(_MSC_VER) || (_MSC_VER >= 1800) */
+#endif /* !(defined(_MSC_VER) && (_MSC_VER < 1800)) */
 #include <sys/types.h>
 #include <stdarg.h>
 #include <stddef.h>
@@ -57,22 +57,22 @@ extern "C" {
 #elif defined(WIN32)
 #  ifdef BUILDING_NGHTTP3
 #    define NGHTTP3_EXTERN __declspec(dllexport)
-#  else /* !BUILDING_NGHTTP3 */
+#  else /* !defined(BUILDING_NGHTTP3) */
 #    define NGHTTP3_EXTERN __declspec(dllimport)
-#  endif /* !BUILDING_NGHTTP3 */
-#else    /* !defined(WIN32) */
+#  endif /* !defined(BUILDING_NGHTTP3) */
+#else    /* !(defined(NGHTTP3_STATICLIB) || defined(WIN32)) */
 #  ifdef BUILDING_NGHTTP3
 #    define NGHTTP3_EXTERN __attribute__((visibility("default")))
-#  else /* !BUILDING_NGHTTP3 */
+#  else /* !defined(BUILDING_NGHTTP3) */
 #    define NGHTTP3_EXTERN
-#  endif /* !BUILDING_NGHTTP3 */
-#endif   /* !defined(WIN32) */
+#  endif /* !defined(BUILDING_NGHTTP3) */
+#endif   /* !(defined(NGHTTP3_STATICLIB) || defined(WIN32)) */
 
 #ifdef _MSC_VER
 #  define NGHTTP3_ALIGN(N) __declspec(align(N))
-#else /* !_MSC_VER */
+#else /* !defined(_MSC_VER) */
 #  define NGHTTP3_ALIGN(N) __attribute__((aligned(N)))
-#endif /* !_MSC_VER */
+#endif /* !defined(_MSC_VER) */
 
 /**
  * @typedef
@@ -1161,8 +1161,8 @@ NGHTTP3_EXTERN void nghttp3_qpack_encoder_del(nghttp3_qpack_encoder *encoder);
  *      anymore.
  */
 NGHTTP3_EXTERN int nghttp3_qpack_encoder_encode(
-    nghttp3_qpack_encoder *encoder, nghttp3_buf *pbuf, nghttp3_buf *rbuf,
-    nghttp3_buf *ebuf, int64_t stream_id, const nghttp3_nv *nva, size_t nvlen);
+  nghttp3_qpack_encoder *encoder, nghttp3_buf *pbuf, nghttp3_buf *rbuf,
+  nghttp3_buf *ebuf, int64_t stream_id, const nghttp3_nv *nva, size_t nvlen);
 
 /**
  * @function
@@ -1182,7 +1182,7 @@ NGHTTP3_EXTERN int nghttp3_qpack_encoder_encode(
  *     |encoder| is unable to process input because it is malformed.
  */
 NGHTTP3_EXTERN nghttp3_ssize nghttp3_qpack_encoder_read_decoder(
-    nghttp3_qpack_encoder *encoder, const uint8_t *src, size_t srclen);
+  nghttp3_qpack_encoder *encoder, const uint8_t *src, size_t srclen);
 
 /**
  * @function
@@ -1343,7 +1343,7 @@ NGHTTP3_EXTERN void nghttp3_qpack_decoder_del(nghttp3_qpack_decoder *decoder);
  *     Could not interpret encoder stream instruction.
  */
 NGHTTP3_EXTERN nghttp3_ssize nghttp3_qpack_decoder_read_encoder(
-    nghttp3_qpack_decoder *decoder, const uint8_t *src, size_t srclen);
+  nghttp3_qpack_decoder *decoder, const uint8_t *src, size_t srclen);
 
 /**
  * @function
@@ -1436,9 +1436,9 @@ nghttp3_qpack_decoder_get_icnt(const nghttp3_qpack_decoder *decoder);
  *     HTTP field is too large.
  */
 NGHTTP3_EXTERN nghttp3_ssize nghttp3_qpack_decoder_read_request(
-    nghttp3_qpack_decoder *decoder, nghttp3_qpack_stream_context *sctx,
-    nghttp3_qpack_nv *nv, uint8_t *pflags, const uint8_t *src, size_t srclen,
-    int fin);
+  nghttp3_qpack_decoder *decoder, nghttp3_qpack_stream_context *sctx,
+  nghttp3_qpack_nv *nv, uint8_t *pflags, const uint8_t *src, size_t srclen,
+  int fin);
 
 /**
  * @function
@@ -1568,7 +1568,7 @@ typedef void (*nghttp3_debug_vprintf_callback)(const char *format,
  *   times because this is important.
  */
 NGHTTP3_EXTERN void nghttp3_set_debug_vprintf_callback(
-    nghttp3_debug_vprintf_callback debug_vprintf_callback);
+  nghttp3_debug_vprintf_callback debug_vprintf_callback);
 
 /**
  * @macrosection
@@ -2106,7 +2106,7 @@ NGHTTP3_EXTERN int nghttp3_conn_bind_qpack_streams(nghttp3_conn *conn,
  * control credit (both stream and connection) of underlying QUIC
  * connection by that amount.  It does not include the amount of data
  * carried by DATA frame which contains application data (excluding
- * any control or QPACK unidirectional streams) .  See
+ * any control or QPACK unidirectional streams).  See
  * :type:`nghttp3_recv_data` to handle those bytes.  If |fin| is
  * nonzero, this is the last data from remote endpoint in this stream.
  *
@@ -2449,8 +2449,8 @@ nghttp3_conn_set_max_concurrent_streams(nghttp3_conn *conn,
  * stream.
  */
 typedef nghttp3_ssize (*nghttp3_read_data_callback)(
-    nghttp3_conn *conn, int64_t stream_id, nghttp3_vec *vec, size_t veccnt,
-    uint32_t *pflags, void *conn_user_data, void *stream_user_data);
+  nghttp3_conn *conn, int64_t stream_id, nghttp3_vec *vec, size_t veccnt,
+  uint32_t *pflags, void *conn_user_data, void *stream_user_data);
 
 /**
  * @struct
@@ -2480,8 +2480,6 @@ typedef struct nghttp3_data_reader {
  * This function returns 0 if it succeeds, or one of the following
  * negative error codes:
  *
- * :macro:`NGHTTP3_ERR_INVALID_ARGUMENT`
- *     |stream_id| identifies unidirectional stream.
  * :macro:`NGHTTP3_ERR_CONN_CLOSING`
  *     Connection is shutting down, and no new stream is allowed.
  * :macro:`NGHTTP3_ERR_STREAM_IN_USE`
@@ -2490,8 +2488,8 @@ typedef struct nghttp3_data_reader {
  *     Out of memory.
  */
 NGHTTP3_EXTERN int nghttp3_conn_submit_request(
-    nghttp3_conn *conn, int64_t stream_id, const nghttp3_nv *nva, size_t nvlen,
-    const nghttp3_data_reader *dr, void *stream_user_data);
+  nghttp3_conn *conn, int64_t stream_id, const nghttp3_nv *nva, size_t nvlen,
+  const nghttp3_data_reader *dr, void *stream_user_data);
 
 /**
  * @function
@@ -2697,7 +2695,7 @@ typedef struct NGHTTP3_ALIGN(8) nghttp3_pri {
  *     Stream not found.
  */
 NGHTTP3_EXTERN int nghttp3_conn_get_stream_priority_versioned(
-    nghttp3_conn *conn, int pri_version, nghttp3_pri *dest, int64_t stream_id);
+  nghttp3_conn *conn, int pri_version, nghttp3_pri *dest, int64_t stream_id);
 
 /**
  * @function
@@ -2750,8 +2748,8 @@ NGHTTP3_EXTERN int nghttp3_conn_set_client_stream_priority(nghttp3_conn *conn,
  *     Out of memory.
  */
 NGHTTP3_EXTERN int nghttp3_conn_set_server_stream_priority_versioned(
-    nghttp3_conn *conn, int64_t stream_id, int pri_version,
-    const nghttp3_pri *pri);
+  nghttp3_conn *conn, int64_t stream_id, int pri_version,
+  const nghttp3_pri *pri);
 
 /**
  * @function
@@ -2914,7 +2912,7 @@ NGHTTP3_EXTERN int nghttp3_err_is_fatal(int liberr);
  */
 #define nghttp3_conn_set_server_stream_priority(CONN, STREAM_ID, PRI)          \
   nghttp3_conn_set_server_stream_priority_versioned(                           \
-      (CONN), (STREAM_ID), NGHTTP3_PRI_VERSION, (PRI))
+    (CONN), (STREAM_ID), NGHTTP3_PRI_VERSION, (PRI))
 
 /*
  * `nghttp3_conn_get_stream_priority` is a wrapper around
@@ -2936,6 +2934,6 @@ NGHTTP3_EXTERN int nghttp3_err_is_fatal(int liberr);
 
 #ifdef __cplusplus
 }
-#endif
+#endif /* defined(__cplusplus) */
 
-#endif /* NGHTTP3_H */
+#endif /* !defined(NGHTTP3_H) */
